==> tine20-allinone_2019.12.5.tar.bz2: Addressbook/js/Addressbook-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:09+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: zh_CN\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Business Contact Data"
: "商业联系人数据"

, "Organisation / Unit"
: "组织/单位"

, "Business Address"
: "商业地址"

, "Email"
: "电子邮件"

, "Telephone Work"
: "工作电话"

, "Telephone Cellphone"
: "手机号码"

, "Telephone Car"
: "车载号码"

, "Telephone Fax"
: "传真号码"

, "Telephone Page"
: "传呼号码"

, "URL"
: "URL"

, "Role"
: "角色"

, "Room"
: "房间"

, "Assistant"
: "助理"

, "Assistant Telephone"
: "助理电话"

, "Private Contact Data"
: "个人联系人数据"

, "Private Address"
: "个人地址"

, "Email Home"
: "家里电子邮件"

, "Telephone Home"
: "家里电话"

, "Telephone Cellphone Private"
: "个人手机号码"

, "Telephone Fax Home"
: "家里传真号码"

, "URL Home"
: "家里 URL"

, "Other Data"
: "其它数据"

, "Birthday"
: "生日"

, "Job Title"
: "工作头衔"

, "Excel all data"
: ""

, "CSV all data"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "OpenDocument all data"
: ""

, "PDF details"
: ""

, "Word letter"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Relations"
: ""

, "List, Lists"
: [
  "列表"

]
, "Percent"
: ""

, "Description"
: "描述"

, "Members"
: ""

, "Type"
: "类型"

, "List type"
: ""

, "Addressbook, Addressbooks"
: [
  "通讯录"

]
, "Contact, Contacts"
: [
  "联系人"

]
, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Country"
: "国家"

, "City"
: "城市"

, "Postalcode"
: "邮政编码"

, "Region"
: "省/自治区/直辖市"

, "Street"
: "街道"

, "Street 2"
: "街道 2"

, "Longitude"
: ""

, "Latitude"
: ""

, "Country (private)"
: "国家（个人）"

, "City (private)"
: "城市（个人）"

, "Postalcode (private)"
: "邮政编码（个人）"

, "Region (private)"
: "省/自治区/直辖市（个人）"

, "Street (private)"
: "街道（个人）"

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Email (private)"
: "电子邮件（个人）"

, "Free/Busy URI"
: ""

, "Geo"
: "地理"

, "Groups"
: ""

, "Industry, Industries"
: [
  ""

]
, "Note"
: "注释"

, "Last Name"
: "姓"

, "Display Name"
: "显示名字"

, "Full Name"
: "全名"

, "First Name"
: "名"

, "Middle Name"
: "中间名"

, "Title"
: "头衔"

, "Suffix"
: "后缀"

, "Company"
: "公司"

, "Unit"
: "单位"

, "Paths"
: ""

, "Preferred Address"
: ""

, "Job Role"
: "工作职责"

, "Salutation"
: "称呼"

, "syncBackendIds"
: ""

, "Car phone"
: "车载电话"

, "Mobile"
: "手机"

, "Mobile (private)"
: "手机（个人）"

, "Fax"
: "传真"

, "Fax (private)"
: "传真（个人）"

, "Phone (private)"
: "电话（个人）"

, "Pager"
: "传呼机"

, "Phone"
: "电话"

, "Timezone"
: "时区"

, "Web"
: "网址"

, "URL (private)"
: "URL（个人）"

, "Label"
: ""

, "Lists"
: "列表"

, "Select list"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "Customfields"
: ""

, "Related to"
: ""

, "Contact Information"
: "联系人信息"

, "Company Address"
: "公司地址"

, "New Contact"
: "新建联系人"

, "ID"
: ""

, "Name"
: "名字"

, "Structure, Structures"
: [
  ""

]
, "Resources"
: ""

, "Import contacts"
: "导入联系人"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Business"
: ""

, "Private"
: "私人"

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "标签"

, "List Roles"
: ""

, "Street (Company Address)"
: "街道 (公司地址)"

, "Street 2 (Company Address)"
: "街道2 (公司地址)"

, "City (Company Address)"
: "城市 (公司地址)"

, "Region (Company Address)"
: "地区 (公司地址)"

, "Postal Code (Company Address)"
: "邮编(公司地址)"

, "Country (Company Address)"
: "国家 (公司地址)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "街道 (私人地址)"

, "Street 2 (Private Address)"
: "街道2 (私人地址)"

, "City (Private Address)"
: "城市 (私人地址)"

, "Region (Private Address)"
: "地区 (私人地址)"

, "Postal Code (Private Address)"
: "邮编 (私人地址)"

, "Country (Private Address)"
: "国家 (私人地址)"

, "Company Communication"
: ""

, "Private Communication"
: ""

, "E-Mail"
: "电子邮件"

, "E-Mail (private)"
: "电子邮件（个人）"

, "Web (private)"
: ""

, "Contacts"
: "联系人"

, "Addressbooks"
: "通讯录"

, "User Account"
: "用户帐户"

, "Quick Search"
: ""

, "Postal Code"
: "邮政编码"

, "Last Modified Time"
: "最后修改时间"

, "Last Modified By"
: "最后修改人"

, "Creation Time"
: "创建时间"

, "Created By"
: "创建人"

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""

]
, "List Functions"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "List Information"
: ""

, "Enter description"
: "输入描述"

, "{0} must be given"
: ""

, "Member of List"
: ""

, "Map"
: "地图"

, "Company address"
: "公司地址"

, "Private address"
: "私人地址"

, "CardDAV URL"
: "CardDAV URL"

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Personal Information"
: "个人信息"

, "Parse address"
: "解析地址"

, "Print contact"
: ""

, "Paste address"
: "粘贴地址"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "结束符的模式"

, "Remove Member"
: ""

, "Emails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "All contacts"
: "所有联系人"

, "Default Addressbook"
: "缺省地址本"

, "The default addressbook for new contacts"
: "新联系人的缺省地址本"

, "Default Favorite"
: "默认收藏夹"

, "The default favorite which is loaded on addressbook startup"
: "打开通讯录时默认加载的收藏夹"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact duplicate check fields"
: "联系人查重字段"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "当创建新联系人时，这些字段将被检查。若与已有记录相同，则报告发生了重复。"

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "称呼"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "列出可能的称呼。注意：当导出或者同步时，附加信息可能会对其它通讯录系统产生影响。"

, "Mr"
: "先生"

, "Ms"
: "女士"

, "Parsing rules for addresses"
: "地址解析规则"

, "Path to a XML file with address parsing rules."
: "含有地址解析规则的XML文件的路径"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Sync Backends"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "导入VCARD联系人"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 German"

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "从Outlook中导入CSV联系人"

, "Contact CSV import from mac address book"
: "从mac通讯录中导入CSV联系人"

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "从谷歌通讯录中导入联系人"

, "manage shared addressbooks"
: "管理共享通讯录"

, "Create new shared addressbook folders"
: "创建新的共享通讯录文件夹"

, "manage shared addressbook favorites"
: "管理共享通讯录的收藏夹"

, "Create or update shared addressbook favorites"
: "创建或更新共享通讯录的收藏夹"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Relation, Relations"
: [
  ""

]
, "%s's personal addressbook"
: "%s 的个人地址本"

, "All contacts I have read grants for"
: ""

, "My company"
: "我的公司"

, "All coworkers in my company"
: "我的公司中的所有同事"

, "My contacts"
: "我的联系人"

, "All contacts in my Addressbooks"
: "我的通讯录中所有联系人"

, "Last modified by me"
: "最后由我修改"

, "All contacts that I have last modified"
: "所有最后由我修改的联系人"

, "Internal Contacts"
: "内部联系人"

, "List"
: "列表"

, "Addressbook"
: "通讯录"

, "Contact"
: "联系人"

, "Industry"
: ""

, "Structure"
: ""

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Addressbook/js/Addressbook-lang-zh_CN-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Addressbook **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Addressbook'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:45+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Map"
: "地图"

, "Preferred Address"
: ""

, "Personal Information"
: "个人信息"

, "Salutation"
: "称呼"

, "Title"
: "头衔"

, "Short Name"
: ""

, "First Name"
: "名"

, "Middle Name"
: "中间名"

, "Last Name"
: "姓"

, "Company"
: "公司"

, "Unit"
: "单位"

, "Display Name"
: "显示名字"

, "Industry, Industries"
: [
  ""

]
, "Job Title"
: "工作头衔"

, "Birthday (private)"
: ""

, "Contact Information"
: "联系人信息"

, "Phone"
: "电话"

, "Mobile"
: "手机"

, "Fax"
: "传真"

, "Phone (private)"
: "电话（个人）"

, "Mobile (private)"
: "手机（个人）"

, "Fax (private)"
: "传真（个人）"

, "E-Mail"
: "电子邮件"

, "E-Mail (private)"
: "电子邮件（个人）"

, "Web"
: "网址"

, "Company Address"
: "公司地址"

, "Street"
: "街道"

, "Street 2"
: "街道 2"

, "Region"
: "省/自治区/直辖市"

, "Postal Code"
: "邮政编码"

, "City"
: "城市"

, "Country"
: "国家"

, "Private Address"
: "个人地址"

, "Description"
: "描述"

, "Enter description"
: "输入描述"

, "Groups"
: ""

, "Parse address"
: "解析地址"

, "Print contact"
: ""

, "Paste address"
: "粘贴地址"

, "Please paste an address or a URI to a vcard that should be parsed:"
: ""

, "Failed to parse address!"
: ""

, "The address could not be read."
: ""

, "End token mode"
: "结束符的模式"

, "Customfields"
: ""

, "Related to"
: ""

, "Mailing List"
: ""

, "This group is a mailing list"
: ""

, "Keep copy of group mails"
: ""

, "Forward external mails"
: ""

, "Only forward member mails"
: ""

, "Only forward to system email accounts"
: ""

, "Search for system groups ..."
: ""

, "Search for groups ..."
: ""

, "Contact, Contacts"
: [
  "联系人"

]
, "Members"
: ""

, "Search for members ..."
: ""

, "List Roles"
: ""

, "Remove Member"
: ""

, "CardDAV URL"
: "CardDAV URL"

, "New Contact"
: "新建联系人"

, "Addressbook, Addressbooks"
: [
  "通讯录"

]
, "ID"
: ""

, "Name"
: "名字"

, "Structure, Structures"
: [
  ""

]
, "Resources"
: ""

, "Private"
: "私人"

, "The grant to access contacts private information"
: ""

, "Contact Personal Grant, Contact Personal Grants"
: [
  ""

]
, "List Personal Grant, List Personal Grants"
: [
  ""

]
, "List Information"
: ""

, "List type"
: ""

, "System accounts only"
: ""

, "{0} must be given"
: ""

, "List Functions"
: ""

, "Suffix"
: "后缀"

, "Birthday"
: "生日"

, "Job Role"
: "工作职责"

, "Room"
: "房间"

, "Street (Company Address)"
: "街道 (公司地址)"

, "Street 2 (Company Address)"
: "街道2 (公司地址)"

, "City (Company Address)"
: "城市 (公司地址)"

, "Region (Company Address)"
: "地区 (公司地址)"

, "Postal Code (Company Address)"
: "邮编(公司地址)"

, "Country (Company Address)"
: "国家 (公司地址)"

, "Longitude (Company Address)"
: ""

, "Latitude (Company Address)"
: ""

, "Street (Private Address)"
: "街道 (私人地址)"

, "Street 2 (Private Address)"
: "街道2 (私人地址)"

, "City (Private Address)"
: "城市 (私人地址)"

, "Region (Private Address)"
: "地区 (私人地址)"

, "Postal Code (Private Address)"
: "邮编 (私人地址)"

, "Country (Private Address)"
: "国家 (私人地址)"

, "Company Communication"
: ""

, "Private Communication"
: ""

, "Web (private)"
: ""

, "Contacts"
: "联系人"

, "Addressbooks"
: "通讯录"

, "User Account"
: "用户帐户"

, "Quick Search"
: ""

, "Type"
: "类型"

, "Last Modified Time"
: "最后修改时间"

, "Last Modified By"
: "最后修改人"

, "Creation Time"
: "创建时间"

, "Created By"
: "创建人"

, "List, Lists"
: [
  "列表"

]
, "Lists"
: "列表"

, "Email Address, Email Addresses"
: [
  ""

]
, "Email Addresses"
: ""

, "Quick search"
: ""

, "List Function, List Functions"
: [
  ""

]
, "GENDER_List Function"
: ""

, "Industries"
: ""

, "Structures"
: ""

, "Business"
: ""

, "Import contacts"
: "导入联系人"

, "Contact of a user account"
: ""

, "No name"
: ""

, "Not set"
: ""

, "Contact Image"
: ""

, "Attachments"
: ""

, "Tags"
: "标签"

, "Full Name"
: "全名"

, "Postalcode"
: "邮政编码"

, "Street (private)"
: "街道（个人）"

, "City (private)"
: "城市（个人）"

, "Region (private)"
: "省/自治区/直辖市（个人）"

, "Postalcode (private)"
: "邮政编码（个人）"

, "Country (private)"
: "国家（个人）"

, "Email"
: "电子邮件"

, "Car phone"
: "车载电话"

, "Pager"
: "传呼机"

, "Email (private)"
: "电子邮件（个人）"

, "URL (private)"
: "URL（个人）"

, "Note"
: "注释"

, "Timezone"
: "时区"

, "Geo"
: "地理"

, "Select list"
: ""

, "Search for users ..."
: ""

, "Search for Contacts ..."
: ""

, "Company address"
: "公司地址"

, "Private address"
: "私人地址"

, "Member E-Mails"
: ""

, "System Group"
: ""

, "Group"
: ""

, "Select record to see its details"
: ""

, "This module visualises hierarchically depended relations between records of different types."
: ""

, "Hierarchically depended relations are created automatically for some data types like users and groups, but can also be created manually via the corresponding relation types."
: ""

, "Loading Structure data..."
: ""

, "All contacts"
: "所有联系人"

, "Default Addressbook"
: "缺省地址本"

, "The default addressbook for new contacts"
: "新联系人的缺省地址本"

, "Default Favorite"
: "默认收藏夹"

, "The default favorite which is loaded on addressbook startup"
: "打开通讯录时默认加载的收藏夹"

, "Contacts ODS export configuration"
: ""

, "Use this configuration for the contact ODS export."
: ""

, "Contacts XLS export configuration"
: ""

, "Use this configuration for the contact XLS export."
: ""

, "default"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Addressbook Application."
: ""

, "Addressbook Contact Event List"
: ""

, "Shows contact events in edit dialog tab panel"
: ""

, "Addressbook List View"
: ""

, "Shows an additional view for lists inside the addressbook"
: ""

, "Addressbook Industries"
: ""

, "Add Industry field to Adressbook"
: ""

, "Mailinglists"
: ""

, "Make group and lists to mailinglists"
: ""

, "Addressbook Short Names"
: ""

, "Add Short Name field to Adressbook"
: ""

, "Manage resources in Addressbook"
: ""

, "Show the resources grid also inside the Addressbook"
: ""

, "Show Structure Panel in Addressbook"
: ""

, "Visualize relations of records"
: ""

, "Contact (id) representing this installation"
: ""

, "Contact duplicate check fields"
: "联系人查重字段"

, "These fields are checked when a new contact is created. If a record with the same data in the fields is found, a duplicate exception is thrown."
: "当创建新联系人时，这些字段将被检查。若与已有记录相同，则报告发生了重复。"

, "Contact Hidden Criteria"
: ""

, "The contact is hidden if it is ... (one of: disabled, expired or never)"
: ""

, "Contact salutations available"
: "称呼"

, "Possible contact salutations. Please note that additional values might impact other Addressbook systems on export or syncronisation."
: "列出可能的称呼。注意：当导出或者同步时，附加信息可能会对其它通讯录系统产生影响。"

, "Mr"
: "先生"

, "Ms"
: "女士"

, "Parsing rules for addresses"
: "地址解析规则"

, "Path to a XML file with address parsing rules."
: "含有地址解析规则的XML文件的路径"

, "List types available"
: ""

, "List types available."
: ""

, "Department"
: ""

, "Mailing list"
: ""

, "Use Nominatim during contact import"
: ""

, "Site Filter"
: ""

, "Filter configuration for site record pickers. Sites can be a special type of contacts/groups for example defined by this filter."
: ""

, "Sync Backends"
: ""

, "Default telephone country code"
: ""

, "%s's personal addressbook"
: "%s 的个人地址本"

, "Business Contact Data"
: "商业联系人数据"

, "Organisation / Unit"
: "组织/单位"

, "Business Address"
: "商业地址"

, "Telephone Work"
: "工作电话"

, "Telephone Cellphone"
: "手机号码"

, "Telephone Car"
: "车载号码"

, "Telephone Fax"
: "传真号码"

, "Telephone Page"
: "传呼号码"

, "URL"
: "URL"

, "Role"
: "角色"

, "Assistant"
: "助理"

, "Assistant Telephone"
: "助理电话"

, "Private Contact Data"
: "个人联系人数据"

, "Email Home"
: "家里电子邮件"

, "Telephone Home"
: "家里电话"

, "Telephone Cellphone Private"
: "个人手机号码"

, "Telephone Fax Home"
: "家里传真号码"

, "URL Home"
: "家里 URL"

, "Other Data"
: "其它数据"

, "OpenDocument all data"
: ""

, "Excel phone list"
: ""

, "Excel phone list grouped by company"
: ""

, "Word details"
: ""

, "Excel overview"
: ""

, "Word letter"
: ""

, "PDF details"
: ""

, "Excel all data"
: ""

, "VCard Report"
: ""

, "Export multiple addressbooks to vcf files"
: ""

, "Relations"
: ""

, "CSV all data"
: ""

, "VCard/VCF"
: ""

, "Export contact data into vcf file"
: ""

, "Addressbooks to export"
: ""

, "Export target"
: ""

, "Import CSV formated contacts from Exchange / Outlook address book"
: ""

, "Contact CSV import from Outlook address book"
: "从Outlook中导入CSV联系人"

, "Contact CSV import from mac address book"
: "从mac通讯录中导入CSV联系人"

, "Import CSV formated contacts from Outlook 2007 German address book"
: ""

, "CSV Outlook 2007 German"
: "CSV Outlook 2007 German"

, "Import CSV formated contacts from Outlook 2010 German address book"
: ""

, "CSV Outlook 2010 German"
: ""

, "Import vCard formated contacts"
: ""

, "Contact VCARD import"
: "导入VCARD联系人"

, "LX-Office CSV Contact import"
: ""

, "Import CSV formated contacts from LX-Office"
: ""

, "Tine 2.0 contact CSV import"
: ""

, "Import CSV formated contacts from Tine 2.0 address book"
: ""

, "Import list (###CURRENTDATE###)"
: ""

, "Contacts imported on ###CURRENTDATE### at ###CURRENTTIME### by ###USERFULLNAME###"
: ""

, "Import CSV formated contacts from Google address book"
: ""

, "Contact import from Google address book"
: "从谷歌通讯录中导入联系人"

, "GENDER_List"
: ""

, "Name/Email"
: ""

, "GENDER_Contact"
: ""

, "Show Disabled"
: ""

, "Path"
: ""

, "List Member"
: ""

, "List Role Member"
: ""

, "Telephone"
: ""

, "Telephone Normalized"
: ""

, "Longitude"
: ""

, "Latitude"
: ""

, "Street 2 (private)"
: ""

, "Longitude (private)"
: ""

, "Latitude (private)"
: ""

, "Assistent"
: ""

, "Calendar URI"
: ""

, "Free/Busy URI"
: ""

, "Paths"
: ""

, "syncBackendIds"
: ""

, "Label"
: ""

, "It is not allowed to add non-account contacts to this list"
: ""

, "E-Mail address is already given. Please choose another one."
: ""

, "It is not allowed to delete a contact linked to an user account!"
: ""

, "This Short Name already exists. How about {0}?"
: ""

, "Internal Contacts"
: "内部联系人"

, "All contacts I have read grants for"
: ""

, "My company"
: "我的公司"

, "All coworkers in my company"
: "我的公司中的所有同事"

, "My contacts"
: "我的联系人"

, "All contacts in my Addressbooks"
: "我的通讯录中所有联系人"

, "Last modified by me"
: "最后由我修改"

, "All contacts that I have last modified"
: "所有最后由我修改的联系人"

, "All Contacts"
: ""

, "This contact has been automatically added by the system as an event attender"
: ""

, "manage shared addressbooks"
: "管理共享通讯录"

, "Create new shared addressbook folders"
: "创建新的共享通讯录文件夹"

, "manage shared addressbook favorites"
: "管理共享通讯录的收藏夹"

, "Create or update shared addressbook favorites"
: "创建或更新共享通讯录的收藏夹"

, "Manage lists in CoreData"
: ""

, "View, create, delete or update lists in CoreData application"
: ""

, "Manage list functions in CoreData"
: ""

, "View, create, delete or update list functions in CoreData application"
: ""

, "Manage list email options"
: ""

, "Manage list email options like mailing lists"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "28"
: ""

, "20"
: ""

, "00877546"
: ""

, "en-GB"
: ""

, "00813B4E"
: ""

, "Gruppenrollen"
: ""

, "00DA3FCD"
: ""

, "00997199"
: ""

, "0009326B"
: ""

, "008C27A5"
: ""

, "00C96397"
: ""

, "00046462"
: ""

, "Relation, Relations"
: [
  ""

]
, "Industry"
: ""

, "Contact"
: "联系人"

, "Addressbook"
: "通讯录"

, "Structure"
: ""

, "Contact Personal Grant"
: ""

, "List Personal Grant"
: ""

, "List"
: "列表"

, "Email Address"
: ""

, "List Function"
: ""

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
